@@ -21,6 +21,7 @@ class Collector:
         self.config: CollectorConfig = loader.load()
 
         adapter_initizlizator = AdaptersInitializer(root_package, self.config.plugins)
+
         self.adapters_with_plugins = adapter_initizlizator.init_adapters()
         self.__api = DataSourceApi(
             http_client=HttpClient(token=self.config.token),
@@ -47,9 +48,7 @@ class Collector:
             for adapter, plugin in self.adapters_with_plugins
         ]
 
-        request = DataSourceList(
-            provider_oddrn=self.config.provider_oddrn, items=data_sources
-        )
+        request = DataSourceList(items=data_sources)
 
         async with ClientSession() as session:
             resp = await self.__api.register_datasource(request, session)
